@@ -1,5 +1,7 @@
 from investing_algorithm_framework.core.workers.worker import Worker
 from investing_algorithm_framework.core.workers.scheduled_worker \
     import ScheduledWorker
+from investing_algorithm_framework.core.workers.relational_worker import \
+    RelationalWorker
 
-__all__ = ['Worker', 'ScheduledWorker']
+__all__ = ['Worker', 'ScheduledWorker', 'RelationalWorker']
