@@ -17,8 +17,17 @@ class Worker(Observable, ABC):
     executing it.
     """
 
-    id = None
-    last_run: datetime = None
+    def __init__(self):
+        super().__init__()
+        self._last_run: datetime = None
+
+    @property
+    def last_run(self):
+        return self._last_run
+
+    @last_run.setter
+    def last_run(self, date_time):
+        self._last_run = date_time
 
     def start(self, **kwargs) -> None:
         """
@@ -26,23 +35,15 @@ class Worker(Observable, ABC):
         it is finished
         """
 
-        try:
-            logger.info("Starting worker {}".format(self.get_id()))
-        except Exception as e:
-            logger.exception(e)
-            return
-
         try:
             self.work(**kwargs)
             self.notify_observers()
             self.update_last_run()
         except Exception as e:
-            logger.error("Error occurred in worker {}".format(self.get_id()))
+            logger.error("Error occurred in worker")
             logger.exception(e)
             self.update_last_run()
 
-        logger.info("Worker {} finished".format(self.get_id()))
-
     @abstractmethod
     def work(self, **kwargs) -> None:
         """
@@ -56,24 +57,12 @@ class Worker(Observable, ABC):
     def remove_observer(self, observer: Observer) -> None:
         super(Worker, self).remove_observer(observer)
 
-    def get_id(self) -> str:
-        assert getattr(self, 'id', None) is not None, (
-            "{} should either include a id attribute, or override the "
-            "`get_id()`, method.".format(self.__class__.__name__)
-        )
-
-        return getattr(self, 'id')
-
-    @classmethod
     @synchronized
-    def update_last_run(cls) -> None:
+    def update_last_run(self) -> None:
         """
         Update last run, this function is synchronized, which means that
         different instances can update the last_run attribute from different
         threads.
         """
-        cls.last_run = datetime.now()
 
-    @classmethod
-    def get_last_run(cls):
-        return cls.last_run
+        self.last_run = datetime.now()
